@@ -1,4 +1,3 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  ActionManager.cs
  *
@@ -72,6 +71,14 @@ namespace Banshee.Base
                     Catalog.GetString("Import Files..."), null,
                     Catalog.GetString("Import files inside a folder"), null),
                     
+                new ActionEntry("ImportMusicAction", Stock.Open,
+                    Catalog.GetString("Import Music..."), null,
+                    Catalog.GetString("Import music from a variety of sources"), null),
+                    
+                new ActionEntry("ImportSourceAction", null,
+                    Catalog.GetString("Import Source"), null,
+                    Catalog.GetString("Import source to library"), null),
+                    
                 new ActionEntry("SelectedSourcePropertiesAction", Stock.Properties,
                     Catalog.GetString("Source Properties..."), null,
                     Catalog.GetString("View source properties"), null),
