@@ -1,4 +1,3 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  Library.cs
  *
@@ -105,6 +104,15 @@ namespace Banshee.Base
             ThreadAssist.Spawn(ReloadLibraryThread);
         }
         
+        public IEnumerable GetGenreList() 
+        {
+            IDataReader reader = Db.Query("SELECT DISTINCT Genre FROM Tracks ORDER BY Genre");
+            while(reader.Read()) {
+                yield return reader["Genre"];
+            }
+            reader.Dispose();
+        }
+
         private void ReloadLibraryThread()
         {
             Tracks.Clear();
@@ -120,6 +128,8 @@ namespace Banshee.Base
                 }
             }
             
+            reader.Dispose();
+            
             is_loaded = true;
             
             ThreadAssist.ProxyToMain(delegate {
