@@ -1,6 +1,5 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
- *  PlaylistSource.cs
+ *  AudioCdSource.cs
  *
  *  Copyright (C) 2005 Novell
  *  Written by Aaron Bockover (aaron@aaronbock.net)
@@ -36,7 +35,7 @@ using Banshee.Base;
 
 namespace Banshee.Sources
 {
-    public class AudioCdSource : Source
+    public class AudioCdSource : Source, IImportSource
     {
         private AudioCdDisk disk;
         
@@ -65,17 +64,24 @@ namespace Banshee.Sources
             return true;
         }
         
+        public void Import()
+        {
+            SourceManager.SetActiveSource(this);
+            Globals.ActionManager["ImportCDAction"].Activate();
+            OnUpdated();
+        }
+        
         private void OnDiskUpdated(object o, EventArgs args)
         {
             ThreadAssist.ProxyToMain(delegate {
                 Name = disk.Title;
+                OnUpdated();
             });
         }
                 
+        private Gdk.Pixbuf icon = IconThemeUtils.LoadIcon(22, "media-cdrom", "gnome-dev-cdrom-audio", "source-cd-audio");
         public override Gdk.Pixbuf Icon {
-            get {
-                return IconThemeUtils.LoadIcon(22, "media-cdrom", "gnome-dev-cdrom-audio", "source-cd-audio");
-            }
+            get { return icon; }
         }
         
         public override IEnumerable Tracks {
