@@ -1,9 +1,8 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  PlayerInterface.cs
  *
- *  Copyright (C) 2005 Novell
- *  Written by Aaron Bockover (aaron@aaronbock.net)
+ *  Copyright (C) 2005-2006 Novell, Inc.
+ *  Written by Aaron Bockover <aaron@abock.org>
  ****************************************************************************/
 
 /*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
@@ -315,12 +314,24 @@ namespace Banshee
             LabelStatusBar = new Label(Catalog.GetString("Banshee Music Player"));
             LabelStatusBar.Show();
             
-            ActionToggleButton shuffle_button = new ActionToggleButton(
+            // Old Shuffle Button
+/*            ActionToggleButton shuffle_button = new ActionToggleButton(
                 Globals.ActionManager["ShuffleAction"], IconSize.Menu);
             shuffle_button.IconSize = IconSize.Menu;
             shuffle_button.Relief = ReliefStyle.None;
-            shuffle_button.ShowAll();
+            shuffle_button.ShowAll();*/
 
+            // Repeat/Shuffle buttons
+            
+            shuffle_toggle_button = new MultiStateToggleButton();
+            shuffle_toggle_button.AddState(typeof(ShuffleDisabledToggleState),
+                    Globals.ActionManager["ShuffleAction"] as ToggleAction);
+            shuffle_toggle_button.AddState(typeof(ShuffleEnabledToggleState),
+                    Globals.ActionManager["ShuffleAction"] as ToggleAction);
+            shuffle_toggle_button.Relief = ReliefStyle.None;
+            shuffle_toggle_button.ShowLabel = false;
+            shuffle_toggle_button.ShowAll();
+            
             repeat_toggle_button = new MultiStateToggleButton();
             repeat_toggle_button.AddState(typeof(RepeatNoneToggleState),
                 Globals.ActionManager["RepeatNoneAction"] as ToggleAction);
@@ -339,7 +350,7 @@ namespace Banshee
             song_properties_button.LabelVisible = false;
             song_properties_button.ShowAll();
             
-            (gxml["BottomToolbar"] as Box).PackStart(shuffle_button, false, false, 0);
+            (gxml["BottomToolbar"] as Box).PackStart(shuffle_toggle_button, false, false, 0);
             (gxml["BottomToolbar"] as Box).PackStart(repeat_toggle_button, false, false, 0);
             (gxml["BottomToolbar"] as Box).PackStart(LabelStatusBar, true, true, 0);
             (gxml["BottomToolbar"] as Box).PackStart(song_properties_button, false, false, 0);
@@ -386,6 +397,7 @@ namespace Banshee
             ((Gtk.ScrolledWindow)gxml["LibraryContainer"]).Add(playlistView);
             playlistView.Show();
             playlistModel.Updated += OnPlaylistUpdated;
+            playlistModel.Stopped += OnPlaylistStopped;
             playlistView.KeyPressEvent += OnPlaylistViewKeyPressEvent;
             playlistView.ButtonPressEvent += OnPlaylistViewButtonPressEvent;
             playlistView.MotionNotifyEvent += OnPlaylistViewMotionNotifyEvent;
@@ -421,6 +433,7 @@ namespace Banshee
             fields.Add(Catalog.GetString("Song Name"));
             fields.Add(Catalog.GetString("Artist Name"));
             fields.Add(Catalog.GetString("Album Title"));
+            fields.Add(Catalog.GetString("Genre"));
             
             searchEntry = new SearchEntry(fields);
             searchEntry.EnterPress += delegate(object o, EventArgs args) {
@@ -439,17 +452,6 @@ namespace Banshee
             gxml["SearchLabel"].Sensitive = false;
             searchEntry.Sensitive = false;
                 
-            // Repeat/Shuffle buttons
-            
-            /* shuffle_toggle_button = new MultiStateToggleButton();
-            shuffle_toggle_button.AddState(typeof(ShuffleDisabledToggleState), gxml["ItemShuffle"] as CheckMenuItem, false);
-            shuffle_toggle_button.AddState(typeof(ShuffleEnabledToggleState), gxml["ItemShuffle"] as CheckMenuItem, true);
-            shuffle_toggle_button.Relief = ReliefStyle.None;
-            shuffle_toggle_button.ShowLabel = false;
-            shuffle_toggle_button.Changed += delegate(object o, ToggleStateChangedArgs args) {
-                //HandleShuffleToggleButton();
-            };
-            shuffle_toggle_button.ShowAll();*/
                 
             toolTips = new Tooltips();
             
@@ -463,7 +465,7 @@ namespace Banshee
             SetTip(sync_dap_button, Catalog.GetString("Synchronize music library to device"));
             SetTip(volumeButton, Catalog.GetString("Adjust volume"));
             SetTip(repeat_toggle_button, Catalog.GetString("Change repeat playback mode"));
-            SetTip(shuffle_button, Catalog.GetString("Toggle shuffle playback mode"));
+            SetTip(shuffle_toggle_button, Catalog.GetString("Toggle shuffle playback mode"));
             SetTip(song_properties_button, Catalog.GetString("Edit and view metadata of selected songs"));
             
             playlistMenuMap = new Hashtable();
@@ -537,35 +539,39 @@ namespace Banshee
         
         private void PromptForImport()
         {
-           HigMessageDialog md = new HigMessageDialog(WindowPlayer, 
-                DialogFlags.Modal, MessageType.Question,
-                Catalog.GetString("Import Music"),
-                Catalog.GetString("Your music library is empty. You may import new music into " +
-                "your library now, or choose to do so later.\n\nAutomatic import " +
-                "or importing a large folder may take a long time, so please " +
-                "be patient."),
-                Catalog.GetString("Import Folder"));
-                
-            md.AddButton(Catalog.GetString("Automatic Import"), ResponseType.Apply, true);
-            md.Response += OnPromptForImportResponse;
-            md.ShowAll();
+            PromptForImport(true);
         }
         
-        private void OnPromptForImportResponse(object o, ResponseArgs args)
+        private void PromptForImport(bool startup)
         {
-            (o as Dialog).Response -= OnPromptForImportResponse;
-            (o as Dialog).Destroy();
+            if(startup) {
+                try {
+                    if(!(bool)Globals.Configuration.Get(GConfKeys.ShowInitialImportDialog)) {
+                        return;
+                    }
+                } catch {
+                }
+            }
             
-            switch(args.ResponseId) {
-                case ResponseType.Ok:
-                    ImportWithFileSelector();
-                    break;
-                case ResponseType.Apply:
-                    ImportHomeDirectory();
-                    break;
+            Banshee.Gui.ImportDialog dialog = new Banshee.Gui.ImportDialog(startup);
+            ResponseType response = dialog.Run();
+            IImportSource import_source = dialog.ActiveSource;
+            
+            if(startup) {
+                Globals.Configuration.Set(GConfKeys.ShowInitialImportDialog, !dialog.DoNotShowAgain);
+            }
+            
+            dialog.Destroy();
+            
+            if(response != ResponseType.Ok) {
+                return;
+            }
+            
+            if(import_source != null) {
+                import_source.Import();
             }
         }
-     
+
         public void SelectAudioCd(string device)
         {
             foreach(Source source in SourceManager.Sources) {
@@ -686,10 +692,21 @@ namespace Banshee
         
         public void UpdateMetaDisplay(TrackInfo ti)
         {
+            if(ti == null) {
+                WindowPlayer.Title = Catalog.GetString("Banshee Music Player");
+                trackInfoHeader.Visible = false;
+                if(trayIcon != null) {
+                    trayIcon.Track = null;
+                }
+                return;
+            }
+        
             trackInfoHeader.Artist = ti.DisplayArtist;
             trackInfoHeader.Title = ti.DisplayTitle;
             trackInfoHeader.Album = ti.DisplayAlbum;
             
+            trackInfoHeader.Visible = true;
+            
             WindowPlayer.Title = ti.DisplayTitle + " (" + ti.DisplayArtist + ")";
             
             try {
@@ -1001,38 +1018,6 @@ namespace Banshee
         }
         
         // ---- Playlist Event Handlers ----
-
-        private void ImportWithFileSelector()
-        {
-            FileChooserDialog chooser = new FileChooserDialog(
-                Catalog.GetString("Import Folder to Library"),
-                null,
-                FileChooserAction.SelectFolder
-            );
-            
-            try {
-                 chooser.SetCurrentFolderUri(Globals.Configuration.Get(GConfKeys.LastFileSelectorUri) as string);
-            } catch(Exception) {
-                 chooser.SetCurrentFolder(Environment.GetFolderPath(Environment.SpecialFolder.Personal));
-            }
-            
-            chooser.AddButton(Stock.Cancel, ResponseType.Cancel);
-            chooser.AddButton(Stock.Open, ResponseType.Ok);
-            chooser.DefaultResponse = ResponseType.Ok;
-            
-            if(chooser.Run() == (int)ResponseType.Ok) { 
-                ImportManager.Instance.QueueSource(chooser.Uri);
-            }
-            
-            Globals.Configuration.Set(GConfKeys.LastFileSelectorUri, chooser.CurrentFolderUri);
-            
-            chooser.Destroy();
-        }
-
-        private void ImportHomeDirectory()
-        {
-            ImportManager.Instance.QueueSource(Environment.GetFolderPath(Environment.SpecialFolder.Personal));
-        }
         
         private void OnPlaylistObjectUpdated(object o, EventArgs args)
         {
@@ -1163,6 +1148,14 @@ namespace Banshee
             Globals.ActionManager.DapActions.Visible = source is DapSource;
             Globals.ActionManager["SelectedSourcePropertiesAction"].Sensitive = source.HasProperties;
             
+            if(source is IImportSource) {
+                Globals.ActionManager["ImportSourceAction"].Visible = source is IImportSource;
+                Globals.ActionManager["ImportSourceAction"].Label = Catalog.GetString("Import") + " '" + 
+                    source.Name + "'";
+            } else {
+                Globals.ActionManager["ImportSourceAction"].Visible = false;
+            }
+            
             if(source is DapSource) {
                 DapSource dapSource = source as DapSource;
                 Globals.ActionManager["SyncDapAction"].Sensitive = !dapSource.Device.IsReadOnly;
@@ -1364,6 +1357,12 @@ namespace Banshee
             playlistView.QueueDraw();
         }
 
+        private void OnPlaylistStopped(object o, EventArgs args)
+        {
+            PlayerEngineCore.ActivePlayer.Close();
+            UpdateMetaDisplay(null);
+        }
+
         private void OnPlaylistUpdated(object o, EventArgs args)
         {
             long count = playlistModel.Count();
@@ -1488,11 +1487,14 @@ namespace Banshee
                 match = ti.Title;
             } else if(field == Catalog.GetString("Album Title")) {
                 match = ti.Album;
+            } else if(field == Catalog.GetString("Genre")) {
+                match = ti.Genre;
             } else {
                 string [] matches = {
                     ti.Artist,
                     ti.Album,
-                    ti.Title
+                    ti.Title,
+                    ti.Genre
                 };
 
                 foreach(string m in matches) {
@@ -1877,7 +1879,7 @@ namespace Banshee
                 playlistView.Selection.SelectPath(path);
         }
      
-        private void OnRipTransactionTrackRipped(object o, HaveTrackInfoArgs args)
+        private void OnAudioCdRipperTrackRipped(object o, HaveTrackInfoArgs args)
         {
             if(SourceManager.ActiveSource is LibrarySource) {
                 ThreadAssist.ProxyToMain(delegate {
@@ -2081,36 +2083,24 @@ namespace Banshee
         
         private void OnImportFolderAction(object o, EventArgs args)
         {
-            ImportWithFileSelector();
+            FolderImportSource.Instance.Import();
         }
         
         private void OnImportFilesAction(object o, EventArgs args)
         {
-            FileChooserDialog chooser = new FileChooserDialog(
-                Catalog.GetString("Import Files to Library"),
-                null,
-                FileChooserAction.Open
-            );
-            
-            try {
-                 chooser.SetCurrentFolderUri(Globals.Configuration.Get(GConfKeys.LastFileSelectorUri) as string);
-            } catch(Exception) {
-                 chooser.SetCurrentFolder(Environment.GetFolderPath(Environment.SpecialFolder.Personal));
+            FileImportSource.Instance.Import();
+        }
+        
+        private void OnImportMusicAction(object o, EventArgs args)
+        {
+            PromptForImport(false);
+        }
+        
+        private void OnImportSourceAction(object o, EventArgs args)
+        {
+            if(sourceView.HighlightedSource is IImportSource) {
+                ((IImportSource)sourceView.HighlightedSource).Import();
             }
-            
-            chooser.AddButton(Stock.Cancel, ResponseType.Cancel);
-            chooser.AddButton(Stock.Open, ResponseType.Ok);
-            
-            chooser.SelectMultiple = true;
-            chooser.DefaultResponse = ResponseType.Ok;
-            
-            if(chooser.Run() == (int)ResponseType.Ok) {
-                ImportManager.Instance.QueueSource(chooser.Uris);
-            }
-            
-            Globals.Configuration.Set(GConfKeys.LastFileSelectorUri, chooser.CurrentFolderUri);
-            
-            chooser.Destroy();
         }
         
         private void OnImportCDAction(object o, EventArgs args)
@@ -2124,12 +2114,12 @@ namespace Banshee
             }
             
             if(list.Count > 0) {
-                RipTransaction trans = new RipTransaction();
-                trans.HaveTrackInfo += OnRipTransactionTrackRipped;
+                AudioCdRipper ripper = new AudioCdRipper();
+                ripper.HaveTrackInfo += OnAudioCdRipperTrackRipped;
                 foreach(AudioCdTrackInfo track in list) {
-                    trans.QueueTrack(track);
+                    ripper.QueueTrack(track);
                 }
-                trans.Run();
+                ripper.Start();
             } else {
                 HigMessageDialog dialog = new HigMessageDialog(WindowPlayer, DialogFlags.Modal, 
                     MessageType.Info, ButtonsType.Ok, 
