@@ -1,9 +1,8 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
 /***************************************************************************
  *  PlaylistModel.cs
  *
- *  Copyright (C) 2005 Novell
- *  Written by Aaron Bockover (aaron@aaronbock.net)
+ *  Copyright (C) 2005-2006 Novell, Inc.
+ *  Written by Aaron Bockover <aaron@abock.org>
  ****************************************************************************/
 
 /*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
@@ -57,6 +56,7 @@ namespace Banshee
         private bool shuffle = false;
         
         public event EventHandler Updated;
+        public event EventHandler Stopped;
         
         public static int NextUid
         {
@@ -74,28 +74,7 @@ namespace Banshee
             };
         }
     
-        public void SyncPlayingIter()
-        {
-            if(PlayerEngineCore.ActivePlayer.Track == null) {
-                playingIter = TreeIter.Zero;
-            } else {
-                for(int i = 0, n = Count(); i < n; i++) {
-                    TreeIter iter;
-                    if(!IterNthChild(out iter, i))
-                        continue;
-                        
-                    TrackInfo ti = IterTrackInfo(iter);
-                    
-                    if(PlayerEngineCore.ActivePlayer.Track.Equals(ti)) {
-                        playingIter = iter;
-                        break;
-                    }
-                }
-            }
-        }
-    
         // --- Load Queue and Additions ---
-    
         private bool OnIdle()
         {
             QueueSync();
@@ -114,7 +93,7 @@ namespace Banshee
 
             trackInfoQueue.Clear();
             trackInfoQueueLocked = false;
-            SyncPlayingIter();
+            //SyncPlayingIter();
             
             return;
         }
@@ -134,6 +113,7 @@ namespace Banshee
         {
             AddTrack(ti, true);
         }
+
         
         public void AddTrack(TrackInfo ti, bool raiseUpdate)
         {
@@ -155,8 +135,6 @@ namespace Banshee
             foreach(TrackInfo track in SourceManager.ActiveSource.Tracks) {
                 AddTrack(track);
             }
-            
-            SyncPlayingIter();
         }
 
         // --- Helper Methods ---
@@ -230,6 +208,16 @@ namespace Banshee
             Advance();
         }
         
+        private void StopPlaying()
+        {
+            EventHandler handler = Stopped;
+            if(handler != null) {
+                handler(this, new EventArgs());
+            }
+            
+            playingIter = TreeIter.Zero;
+        }
+        
         private void ChangeDirection(bool forward)
         {
             // TODO: Implement random playback without repeating a track 
@@ -248,9 +236,12 @@ namespace Banshee
             
             if(currentPath == null) {
                 if(shuffle) {
-                    if(!GetRandomTrackIter(out nextIter))
+                    if(!GetRandomTrackIter(out nextIter)) {
+                        StopPlaying();
                         return;
+                    }
                 } else if(!GetIterFirst(out nextIter)) {
+                    StopPlaying();
                     return;
                 }
 
@@ -262,8 +253,10 @@ namespace Banshee
             int index = FindIndex(currentPath);
             bool lastTrack = index == count - 1;
         
-            if(count <= 0 || index >= count || index < 0)
+            if(count <= 0 || index >= count || index < 0) {
+                StopPlaying();
                 return;
+            }
                 
             currentTrack = PathTrackInfo(currentPath);
             currentIter = playingIter;
@@ -272,15 +265,21 @@ namespace Banshee
                 nextIter = currentIter;
             } else if(forward) {
                 if(lastTrack && repeat == RepeatMode.All) {
-                    if(!IterNthChild(out nextIter, 0))
+                    if(!IterNthChild(out nextIter, 0)) {
+                        StopPlaying();
                         return;
+                    }
                 } else if(shuffle) {
-                    if(!GetRandomTrackIter(out nextIter))
+                    if(!GetRandomTrackIter(out nextIter)) {
+                        StopPlaying();
                         return;
+                    }
                 } else {                
                     currentPath.Next();                
-                    if(!GetIter(out nextIter, currentPath))
+                    if(!GetIter(out nextIter, currentPath)) {
+                        StopPlaying();
                         return;
+                    }
                 }
                 
                 nextTrack = IterTrackInfo(nextIter);
@@ -289,9 +288,11 @@ namespace Banshee
                 if(currentTrack.PreviousTrack.Equals(TreeIter.Zero)) {
                     if(index > 0 && currentPath.Prev()) {
                         if(!GetIter(out nextIter, currentPath)) {
+                            StopPlaying();
                             return;
                         }
                     } else {
+                        StopPlaying();
                         return;
                     }
                 } else {
@@ -299,8 +300,11 @@ namespace Banshee
                 }
             }
             
-            if(!nextIter.Equals(TreeIter.Zero))
+            if(!nextIter.Equals(TreeIter.Zero)) {
                 PlayIter(nextIter);
+            } else {
+                StopPlaying();
+            }
         }
 
         public int Count()
@@ -418,8 +422,11 @@ namespace Banshee
             }
         }
         
-        public TreeIter PlayingIter
-        {
+        public TreeIter PlayingIter {
+            set {
+                playingIter = value;
+            }
+
             get {
                 return playingIter;
             }
