@@ -1,4 +1,4 @@
-/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
+
 /***************************************************************************
  *  SourceView.cs
  *
@@ -87,21 +87,16 @@ namespace Banshee
             RefreshList();
             
             SourceManager.SourceAdded += delegate(SourceAddedArgs args) {
-                TreeIter iter = store.Insert(args.Position);
-                store.SetValue(iter, 0, args.Source);
+                if(FindSource(args.Source).Equals(TreeIter.Zero)) {
+                    TreeIter iter = store.Insert(args.Position);
+                    store.SetValue(iter, 0, args.Source);
+                }
             };
             
             SourceManager.SourceRemoved += delegate(SourceEventArgs args) {
-                for(int i = 0, n = store.IterNChildren(); i < n; i++) {
-                    TreeIter iter = TreeIter.Zero;
-                    if(!store.IterNthChild(out iter, i)) {
-                        continue;
-                    }
-                    
-                    if((store.GetValue(iter, 0) as Source) == args.Source) {
-                        store.Remove(ref iter);
-                        return;
-                    }
+                TreeIter iter = FindSource(args.Source);
+                if(!iter.Equals(TreeIter.Zero)) {
+                    store.Remove(ref iter);
                 }
             };
             
@@ -113,6 +108,21 @@ namespace Banshee
                 QueueDraw();
             };
         }
+
+        private TreeIter FindSource(Source source) {
+            for(int i = 0, n = store.IterNChildren(); i < n; i++) {
+                TreeIter iter = TreeIter.Zero;
+                if(!store.IterNthChild(out iter, i)) {
+                    continue;
+                }
+                
+                if((store.GetValue(iter, 0) as Source) == source) {
+                    return iter;
+                }
+            }
+
+            return TreeIter.Zero;
+        }
                     
         protected void SourceCellDataFunc(TreeViewColumn tree_column,
             CellRenderer cell, TreeModel tree_model, TreeIter iter)
